@@ -125,8 +125,9 @@ class DeviceModel:
 
     @property
     def battery_level(self) -> int:
-        """Returns the battery level of the device."""
-        return int(self.properties.get("batteryLevel", 0))
+        """Returns the battery level of the device in percent."""
+        percent = int(self.properties.get("batteryLevel", 0))
+        return 0 if percent == 255 else percent
 
     @property
     def has_battery_level(self) -> bool:
@@ -145,6 +146,28 @@ class DeviceModel:
         """Returns true if the device has a unit property."""
         return "armed" in self.properties
 
+    @property
+    def dead(self) -> bool:
+        """Returns the state if the device is reachable if supported,
+        otherwise False is returned.
+        """
+        return _to_bool(self.properties.get("dead", False))
+
+    @property
+    def has_dead(self) -> bool:
+        """Returns true if the device has a dead property."""
+        return "dead" in self.properties
+
+    @property
+    def dead_reason(self) -> str | None:
+        """Returns the dead reason or None if not supported."""
+        return self.properties.get("deadReason")
+
+    @property
+    def has_dead_reason(self) -> bool:
+        """Returns true if the device has a deadReason property."""
+        return "deadReason" in self.properties
+
     @property
     def value(self) -> ValueModel:
         """Returns the value info."""
@@ -205,7 +228,7 @@ class DeviceModel:
         """Returns the supported modes, for example for fan or hvac devices."""
         if "supportedModes" in self.properties:
             modes = self.properties.get("supportedModes")
-            if isinstance(modes, str):
+            if isinstance(modes, str) and modes != "":
                 return [int(mode) for mode in modes.split(",")]
             if isinstance(modes, list):
                 return [int(mode) for mode in modes]
@@ -231,7 +254,7 @@ class DeviceModel:
         """Returns the supported operating modes, for example for fan or hvac devices."""
         if "supportedOperatingModes" in self.properties:
             modes = self.properties.get("supportedOperatingModes")
-            if isinstance(modes, str):
+            if isinstance(modes, str) and modes != "":
                 return [int(mode) for mode in modes.split(",")]
             if isinstance(modes, list):
                 return [int(mode) for mode in modes]
@@ -301,6 +324,28 @@ class DeviceModel:
         """Returns the target level or 0 if there is no value."""
         return float(self.properties.get("targetLevel", 0.0))
 
+    @property
+    def has_central_scene_event(self) -> bool:
+        """Returns true if the device can issue central scene events."""
+        return "centralSceneSupport" in self.properties
+
+    @property
+    def central_scene_event(self) -> list[SceneEvent]:
+        """Returns list of potential scene events."""
+        central_scene_support = []
+        value = self.properties.get("centralSceneSupport")
+        if isinstance(value, list):
+            central_scene_support = value
+        if isinstance(value, str):
+            central_scene_support = json.loads(value)
+
+        result = []
+        for central_scene in central_scene_support:
+            key_id = int(central_scene.get("keyId"))
+            key_attributes = central_scene.get("keyAttributes")
+            result.append(SceneEvent(key_id, key_attributes))
+        return result
+
     def execute_action(self, action: str, arguments: list[Any] | None = None) -> Any:
         """Execute a device action.
 
@@ -337,7 +382,8 @@ class DeviceModel:
             if device.get("type") in IGNORE_DEVICE:
                 _LOGGER.debug("Ignore device: %s", device.get("id"))
             elif "id" not in device or "name" not in device:
-                _LOGGER.debug("Ignore device because it does not contain id or name")
+                _LOGGER.debug(
+                    "Ignore device because it does not contain id or name")
             else:
                 devices.append(device)
         return [DeviceModel(data, rest_client, api_version) for data in devices]
@@ -470,7 +516,7 @@ class ColorModel:
             try:
                 self.rgbw_color
                 return True
-            except TypeError:
+            except (TypeError, ValueError):
                 return False
         return False
 
@@ -489,3 +535,22 @@ class ColorModel:
         if len(rgbw) != 4:
             raise TypeError(f"Color does not have 4 parts: {color}")
         return rgbw
+
+
+class SceneEvent:
+    """Model to read out the scene events."""
+
+    def __init__(self, key_id: int, key_attributes: list[str]) -> None:
+        """Constructor."""
+        self._key_id = key_id
+        self._key_attributes = key_attributes
+
+    @property
+    def key_id(self) -> int:
+        """Returns the key id."""
+        return self._key_id
+
+    @property
+    def key_event_types(self) -> list[str]:
+        """Returns the possible key event types."""
+        return self._key_attributes
